@@ -7,14 +7,16 @@ def fuzzy_match(needle, hay, flags=re.DOTALL, needle_length_window=0.2):
     Code adapted from: 
     https://stackoverflow.com/questions/17740833/checking-fuzzy-approximate-substring-existing-in-a-longer-string-in-python/31433394#31433394
     """
-    matched = re.search(needle, hay, flags=flags)
+    try:
+        matched = re.search(needle, hay, flags=flags)
+    except:
+        pass
     if matched is not None:
         return matched
     try:
         gen = list(find_near_matches(needle, hay, max_l_dist=5))
         if len(gen) > 0:
             return gen[0]
-    # exception handling here
     except (StopIteration, RuntimeError):
         return
 
